#ifndef EL__ECMASCRIPT_MUJS_LOCALSTORAGE_H
#define EL__ECMASCRIPT_MUJS_LOCALSTORAGE_H

#include <mujs.h>

#ifdef __cplusplus
extern "C" {
#endif

int mjs_localstorage_init(js_State *J);

#ifdef __cplusplus
}
#endif

#endif
